@@ -4,110 +4,138 @@
 <context>
     <name>BatteryHelper</name>
     <message>
-        <location filename="../batteryhelper.cpp" line="42"/>
+        <location filename="../batteryhelper.cpp" line="44"/>
         <source>Empty</source>
         <translation>Пустая</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="44"/>
+        <location filename="../batteryhelper.cpp" line="46"/>
         <source>Discharging</source>
         <translation>Разряжается</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="46"/>
+        <location filename="../batteryhelper.cpp" line="48"/>
         <source>Fully charged</source>
         <translation>Полностью заряжена</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="49"/>
+        <location filename="../batteryhelper.cpp" line="51"/>
         <source>Charging</source>
         <translation>Заряжается</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="58"/>
+        <location filename="../batteryhelper.cpp" line="60"/>
         <source>Lithium ion</source>
         <translation>Литий-ионная</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="60"/>
+        <location filename="../batteryhelper.cpp" line="62"/>
         <source>Lithium polymer</source>
         <translation>Литий-полимерная</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="62"/>
+        <location filename="../batteryhelper.cpp" line="64"/>
         <source>Lithium iron phosphate</source>
         <translation>Литий-железо-фосфатная</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="64"/>
+        <location filename="../batteryhelper.cpp" line="66"/>
         <source>Lead acid</source>
         <translation>Свинцово-кислотная</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="66"/>
+        <location filename="../batteryhelper.cpp" line="68"/>
         <source>Nickel cadmium</source>
         <translation>Никель-кадмиевая</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="68"/>
+        <location filename="../batteryhelper.cpp" line="70"/>
         <source>Nickel metal hydride</source>
         <translation>Никель-метал-гидридная</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="71"/>
+        <location filename="../batteryhelper.cpp" line="73"/>
         <source>Unknown</source>
         <translation>Неизвестно</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="80"/>
+        <location filename="../batteryhelper.cpp" line="82"/>
         <source>Personal Digital Assistant&apos;s battery</source>
         <translation>Батарея карманного персонального компьютера</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="82"/>
+        <location filename="../batteryhelper.cpp" line="84"/>
         <source>Uninterruptible Power Supply&apos;s battery</source>
         <translation>Батарея источника бесперебойного электропитания</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="84"/>
+        <location filename="../batteryhelper.cpp" line="86"/>
         <source>Primary battery</source>
         <translation>Основная батарея</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="86"/>
+        <location filename="../batteryhelper.cpp" line="88"/>
         <source>Mouse battery</source>
         <translation>Батарея мыши</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="88"/>
+        <location filename="../batteryhelper.cpp" line="90"/>
         <source>Keyboard battery</source>
         <translation>Батарея клавиатуры</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="90"/>
+        <location filename="../batteryhelper.cpp" line="92"/>
         <source>Keyboard and mouse&apos;s battery</source>
         <translation>Батарея мыши и клавиатуры</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="92"/>
+        <location filename="../batteryhelper.cpp" line="94"/>
         <source>Camera battery</source>
         <translation>Батарея камеры</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="94"/>
+        <location filename="../batteryhelper.cpp" line="96"/>
         <source>Phone battery</source>
         <translation>Батарея телефона</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="96"/>
+        <location filename="../batteryhelper.cpp" line="98"/>
         <source>Monitor battery</source>
         <translation>Батарея монитора</translation>
     </message>
     <message>
-        <location filename="../batteryhelper.cpp" line="99"/>
+        <location filename="../batteryhelper.cpp" line="101"/>
         <source>Unknown battery</source>
         <translation>Неизвестная батарея</translation>
     </message>
+    <message numerus="yes">
+        <location filename="../batteryhelper.cpp" line="111"/>
+        <source>%n hour(s)</source>
+        <translation>
+            <numerusform>час</numerusform>
+            <numerusform>часа</numerusform>
+            <numerusform>часов</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../batteryhelper.cpp" line="112"/>
+        <source>%n minute(s)</source>
+        <translation>
+            <numerusform>минута</numerusform>
+            <numerusform>минуты</numerusform>
+            <numerusform>минут</numerusform>
+        </translation>
+    </message>
+    <message>
+        <location filename="../batteryhelper.cpp" line="117"/>
+        <source>remaining %1</source>
+        <translation>осталось %1</translation>
+    </message>
+    <message>
+        <location filename="../batteryhelper.cpp" line="122"/>
+        <source>to full %1</source>
+        <translation>до полной зарядки %1</translation>
+    </message>
 </context>
 <context>
     <name>BatteryInfoDialog</name>
@@ -193,12 +221,12 @@
         <translation>LXQt не смог найти информацию о какой-либо батарее - наблюдение отменено</translation>
     </message>
     <message>
-        <location filename="../batterywatcher.cpp" line="114"/>
+        <location filename="../batterywatcher.cpp" line="119"/>
         <source>Power low!</source>
         <translation>Низкий заряд!</translation>
     </message>
     <message numerus="yes">
-        <location filename="../batterywatcher.cpp" line="126"/>
+        <location filename="../batterywatcher.cpp" line="131"/>
         <source>Suspending in %n second(s)</source>
         <translation>
             <numerusform>Ждущий режим через %n секунду</numerusform>
@@ -207,7 +235,7 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../batterywatcher.cpp" line="129"/>
+        <location filename="../batterywatcher.cpp" line="134"/>
         <source>Hibernating in %n second(s)</source>
         <translation>
             <numerusform>Гибернация через %n секунду</numerusform>
@@ -216,7 +244,7 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../batterywatcher.cpp" line="132"/>
+        <location filename="../batterywatcher.cpp" line="137"/>
         <source>Shutting down in %n second(s)</source>
         <translation>
             <numerusform>Выключение через %n секунду</numerusform>
@@ -240,7 +268,7 @@
     <message>
         <location filename="../powerbutton.cpp" line="86"/>
         <source>Hibernate key action</source>
-        <translation type="unfinished"></translation>
+        <translation>Действие кнопки «Спящий режим»</translation>
     </message>
 </context>
 <context>
@@ -266,38 +294,68 @@ You can configure it from settings... </source>
 <context>
     <name>TrayIcon</name>
     <message>
-        <location filename="../trayicon.cpp" line="63"/>
-        <location filename="../trayicon.cpp" line="94"/>
+        <location filename="../trayicon.cpp" line="101"/>
+        <location filename="../trayicon.cpp" line="191"/>
         <source>About</source>
         <translation>О программе</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="61"/>
+        <location filename="../trayicon.cpp" line="67"/>
         <source>Configure</source>
         <translation>Настроить</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="65"/>
+        <location filename="../trayicon.cpp" line="75"/>
+        <source>30 minutes</source>
+        <translation>30 минут</translation>
+    </message>
+    <message>
+        <location filename="../trayicon.cpp" line="79"/>
+        <source>1 hour</source>
+        <translation>1 час</translation>
+    </message>
+    <message>
+        <location filename="../trayicon.cpp" line="83"/>
+        <source>2 hours</source>
+        <translation>2 часа</translation>
+    </message>
+    <message>
+        <location filename="../trayicon.cpp" line="87"/>
+        <source>3 hours</source>
+        <translation>3 часа</translation>
+    </message>
+    <message>
+        <location filename="../trayicon.cpp" line="91"/>
+        <source>4 hours</source>
+        <translation>4 часа</translation>
+    </message>
+    <message>
+        <location filename="../trayicon.cpp" line="96"/>
+        <source>Pause idleness checks</source>
+        <translation>Приостановить проверку бездействия</translation>
+    </message>
+    <message>
+        <location filename="../trayicon.cpp" line="103"/>
         <source>Disable icon</source>
         <translation>Не показывать значок</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="95"/>
+        <location filename="../trayicon.cpp" line="192"/>
         <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
         <translation>&lt;p&gt;  &lt;b&gt;Управление энергопотреблением LXQt&lt;/b&gt;&lt;br/&gt;  - Управление энергопотреблением для окружения рабочего стола LXQt&lt;/p&gt;&lt;p&gt; Авторы:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - и другие из проектов Razor и LXQt&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="113"/>
+        <location filename="../trayicon.cpp" line="210"/>
         <source>LXQt Power Management info</source>
         <translation>Сведения об управлении энергопотреблением LXQt</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="114"/>
+        <location filename="../trayicon.cpp" line="211"/>
         <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
         <translation>Значок в системном лотке для управление энергопотреблением может быть включён в &lt;i&gt;Настройках управления энергопотреблением&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="116"/>
+        <location filename="../trayicon.cpp" line="213"/>
         <source>Configure now</source>
         <translation>Настроить сейчас</translation>
     </message>
